@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -904,7 +905,7 @@ Pointer  __EXPORT SwVirtFlyDrawObj::GetMacroPointer(
 }
 
 
-FASTBOOL __EXPORT SwVirtFlyDrawObj::HasMacro() const
+bool __EXPORT SwVirtFlyDrawObj::HasMacro() const
 {
     const SwFmtURL &rURL = pFlyFrm->GetFmt()->GetURL();
     return rURL.GetMap() || rURL.GetURL().Len();
@@ -960,3 +961,5 @@ SdrObject* SwVirtFlyDrawObj::getFullDragClone() const
 }
 
 // eof
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
