@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -332,7 +333,7 @@ void SwAttrHandler::SwAttrStack::Insert( const SwTxtAttr& rAttr, const USHORT nP
         }
     }
 
-    ASSERT( nPos <= nCount, "wrong position for insert operation");
+    OSL_ENSURE( nPos <= nCount, "wrong position for insert operation");
 
     if ( nPos < nCount )
         memmove( pArray + nPos + 1, pArray + nPos,
@@ -520,7 +521,7 @@ void SwAttrHandler::PushAndChg( const SwTxtAttr& rAttr, SwFont& rFnt )
 
 sal_Bool SwAttrHandler::Push( const SwTxtAttr& rAttr, const SfxPoolItem& rItem )
 {
-    ASSERT( rItem.Which() < RES_TXTATR_WITHEND_END,
+    OSL_ENSURE( rItem.Which() < RES_TXTATR_WITHEND_END,
             "I do not want this attribute, nWhich >= RES_TXTATR_WITHEND_END" );
 
     // robust
@@ -541,7 +542,7 @@ sal_Bool SwAttrHandler::Push( const SwTxtAttr& rAttr, const SfxPoolItem& rItem )
     }
 
     USHORT nPos = aAttrStack[ nStack ].Count();
-    ASSERT( nPos, "empty stack?" );
+    OSL_ENSURE( nPos, "empty stack?" );
     aAttrStack[ nStack ].Insert( rAttr, nPos - 1 );
     return sal_False;
 }
@@ -598,7 +599,7 @@ void SwAttrHandler::PopAndChg( const SwTxtAttr& rAttr, SwFont& rFnt )
 
 void SwAttrHandler::Pop( const SwTxtAttr& rAttr )
 {
-    ASSERT( rAttr.Which() < RES_TXTATR_WITHEND_END,
+    OSL_ENSURE( rAttr.Which() < RES_TXTATR_WITHEND_END,
             "I do not have this attribute, nWhich >= RES_TXTATR_WITHEND_END" );
 
     if ( rAttr.Which() < RES_TXTATR_WITHEND_END )
@@ -612,7 +613,7 @@ void SwAttrHandler::Pop( const SwTxtAttr& rAttr )
  *************************************************************************/
 void SwAttrHandler::ActivateTop( SwFont& rFnt, const USHORT nAttr )
 {
-    ASSERT( nAttr < RES_TXTATR_WITHEND_END,
+    OSL_ENSURE( nAttr < RES_TXTATR_WITHEND_END,
             "I cannot activate this attribute, nWhich >= RES_TXTATR_WITHEND_END" );
 
     const USHORT nStackPos = StackPos[ nAttr ];
@@ -944,7 +945,7 @@ void SwAttrHandler::FontChg(const SfxPoolItem& rItem, SwFont& rFnt, sal_Bool bPu
 void SwAttrHandler::GetDefaultAscentAndHeight( ViewShell* pShell, OutputDevice& rOut,
                                                USHORT& nAscent, USHORT& nHeight ) const
 {
-    ASSERT( pFnt, "No font available for GetDefaultAscentAndHeight" )
+    OSL_ENSURE( pFnt, "No font available for GetDefaultAscentAndHeight" );
 
     if ( pFnt )
     {
@@ -954,3 +955,4 @@ void SwAttrHandler::GetDefaultAscentAndHeight( ViewShell* pShell, OutputDevice&
     }
 }
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
