@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -45,12 +46,8 @@
 #include <mvsave.hxx>
 #include <redline.hxx>
 #include <crossrefbookmark.hxx>
-#ifndef _UNDO_HRC
 #include <undo.hrc>
-#endif
-#ifndef _COMCORE_HRC
 #include <comcore.hrc>
-#endif
 #include <docsh.hxx>
 
 class SwRedlineSaveData : public SwUndRng, public SwRedlineData,
@@ -65,7 +62,7 @@ public:
     SwNodeIndex* GetMvSttIdx() const
         { return SwUndoSaveSection::GetMvSttIdx(); }
 
-#ifdef DBG_UTIL
+#if OSL_DEBUG_LEVEL > 1
     USHORT nRedlineCount;
 #endif
 };
@@ -438,7 +435,7 @@ void SwUndoSaveCntnt::MoveFromUndoNds( SwDoc& rDoc, ULONG nNodeIdx,
 
     }
     else {
-        ASSERT( FALSE, "was ist es denn nun?" );
+        OSL_ENSURE( FALSE, "was ist es denn nun?" );
     }
 
     rDoc.DoUndo( bUndo );
@@ -539,7 +536,7 @@ void SwUndoSaveCntnt::DelCntntIndex( const SwPosition& rMark,
                     pHistory = new SwHistory;
                 SwTxtAttr* const pFtnHnt =
                     pTxtNd->GetTxtAttrForCharAt( nFtnSttIdx );
-                ASSERT( pFtnHnt, "kein FtnAttribut" );
+                OSL_ENSURE( pFtnHnt, "kein FtnAttribut" );
                 SwIndex aIdx( pTxtNd, nFtnSttIdx );
                 pHistory->Add( pFtnHnt, pTxtNd->GetIndex(), false );
                 pTxtNd->EraseText( aIdx, 1 );
@@ -563,7 +560,7 @@ void SwUndoSaveCntnt::DelCntntIndex( const SwPosition& rMark,
                     pHistory = new SwHistory;
                 SwTxtAttr* const pFtnHnt =
                     pTxtNd->GetTxtAttrForCharAt( nFtnSttIdx );
-                ASSERT( pFtnHnt, "kein FtnAttribut" );
+                OSL_ENSURE( pFtnHnt, "kein FtnAttribut" );
                 SwIndex aIdx( pTxtNd, nFtnSttIdx );
                 pHistory->Add( pFtnHnt, pTxtNd->GetIndex(), false );
                 pTxtNd->EraseText( aIdx, 1 );
@@ -602,7 +599,7 @@ void SwUndoSaveCntnt::DelCntntIndex( const SwPosition& rMark,
                         SwTxtNode* pTxtNd = pDoc->GetNodes()[ pAPos->nNode]->GetTxtNode();
                         SwTxtAttr* const pFlyHnt = pTxtNd->GetTxtAttrForCharAt(
                             pAPos->nContent.GetIndex());
-                        ASSERT( pFlyHnt, "kein FlyAttribut" );
+                        OSL_ENSURE( pFlyHnt, "kein FlyAttribut" );
                         pHistory->Add( pFlyHnt, 0, false );
                         // n wieder zurueck, damit nicht ein Format uebesprungen wird !
                         n = n >= rSpzArr.Count() ? rSpzArr.Count() : n+1;
@@ -882,7 +879,7 @@ void SwUndoSaveSection::RestoreSection( SwDoc* pDoc, SwNodeIndex* pIdx,
     {
         // ueberpruefe, ob der Inhalt an der alten Position steht
         SwNodeIndex aSttIdx( pDoc->GetNodes(), nStartPos );
-        ASSERT( !pDoc->GetNodes()[ aSttIdx ]->GetCntntNode(),
+        OSL_ENSURE( !pDoc->GetNodes()[ aSttIdx ]->GetCntntNode(),
                 "Position in irgendeiner Section" );
 
         // move den Inhalt aus dem UndoNodes-Array in den Fly
@@ -1049,7 +1046,7 @@ SwRedlineSaveData::SwRedlineSaveData( SwComparePosition eCmpPos,
     : SwUndRng( rRedl ),
     SwRedlineData( rRedl.GetRedlineData(), bCopyNext )
 {
-    ASSERT( POS_OUTSIDE == eCmpPos ||
+    OSL_ENSURE( POS_OUTSIDE == eCmpPos ||
             !rRedl.GetContentIdx(), "Redline mit Content" );
 
     switch( eCmpPos )
@@ -1083,10 +1080,10 @@ SwRedlineSaveData::SwRedlineSaveData( SwComparePosition eCmpPos,
         break;
 
     default:
-        ASSERT( !this, "keine gueltigen Daten!" )
+        OSL_ENSURE( !this, "keine gueltigen Daten!" );
     }
 
-#ifdef DBG_UTIL
+#if OSL_DEBUG_LEVEL > 1
     nRedlineCount = rSttPos.nNode.GetNode().GetDoc()->GetRedlineTbl().Count();
 #endif
 }
@@ -1257,7 +1254,7 @@ BOOL SwUndo::CanRedlineGroup( SwRedlineSaveDatas& rCurr,
 // #111827#
 String ShortenString(const String & rStr, xub_StrLen nLength, const String & rFillStr)
 {
-    ASSERT( nLength - rFillStr.Len() >= 2, "improper arguments")
+    OSL_ENSURE( nLength - rFillStr.Len() >= 2, "improper arguments");
 
     String aResult;
 
@@ -1402,3 +1399,4 @@ bool IsDestroyFrameAnchoredAtChar(SwPosition const & rAnchorPos,
             );
 }
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
