@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -575,7 +576,7 @@ void SwHTMLParser::NewNumBulListItem( int nToken )
 
         pDoc->MakeNumRule( aNumRuleName, &aNumRule );
 
-        ASSERT( !nOpenParaToken,
+        OSL_ENSURE( !nOpenParaToken,
                 "Jetzt geht ein offenes Absatz-Element verloren" );
         // Wir tun so, als ob wir in einem Absatz sind. Dann wird
         // beim naechsten Absatz wenigstens die Numerierung
@@ -686,9 +687,9 @@ void SwHTMLParser::EndNumBulListItem( int nToken, sal_Bool bSetColl,
 void SwHTMLParser::SetNodeNum( sal_uInt8 nLevel, bool bCountedInList )
 {
     SwTxtNode* pTxtNode = pPam->GetNode()->GetTxtNode();
-    ASSERT( pTxtNode, "Kein Text-Node an PaM-Position" );
+    OSL_ENSURE( pTxtNode, "Kein Text-Node an PaM-Position" );
 
-    ASSERT( GetNumInfo().GetNumRule(), "Kein Numerierungs-Regel" );
+    OSL_ENSURE( GetNumInfo().GetNumRule(), "Kein Numerierungs-Regel" );
     const String& rName = GetNumInfo().GetNumRule()->GetName();
     ((SwCntntNode *)pTxtNode)->SetAttr( SwNumRuleItem(rName) );
 
@@ -809,7 +810,7 @@ Writer& OutHTML_NumBulListStart( SwHTMLWriter& rWrt,
                                 break;
                             }
 
-                            ASSERT(! pTxtNd->IsOutline(),
+                            OSL_ENSURE(! pTxtNd->IsOutline(),
                                    "outline not expected");
 
                             if( pTxtNd->GetActualListLevel() + 1 <
@@ -923,7 +924,7 @@ Writer& OutHTML_NumBulListStart( SwHTMLWriter& rWrt,
                 }
                 else
                 {
-                    ASSERT( false,
+                    OSL_ENSURE( false,
                             "<OutHTML_NumBulListStart(..) - text node has no number." );
                 }
             }
@@ -985,3 +986,5 @@ Writer& OutHTML_NumBulListEnd( SwHTMLWriter& rWrt,
 
     return rWrt;
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
