@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -27,7 +28,6 @@
 
 // MARKER(update_precomp.py): autogen include statement, do not remove
 #include "precompiled_sw.hxx"
-/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil -*- */
 #include <hintids.hxx>
 #include <tools/list.hxx>
 #include <tools/cachestr.hxx>
@@ -61,6 +61,7 @@
 #include <txtflcnt.hxx>
 #include <fmtflcnt.hxx>
 #include <fltini.hxx>
+#include <unoframe.hxx>
 #include <deque>
 #include <map>
 #include <utility>
@@ -236,9 +237,9 @@ void SwRTFParser::SetFlysInDoc()
     {
         SwFlySave* pFlySave = aFlyArr[ n ];
 
-        ASSERT( !pFlySave->nSttNd.GetNode().FindFlyStartNode(),
+        OSL_ENSURE( !pFlySave->nSttNd.GetNode().FindFlyStartNode(),
                 "Content vom Fly steht in einem Fly" );
-        ASSERT( pFlySave->nSttNd.GetIndex() <= pFlySave->nEndNd.GetIndex(),
+        OSL_ENSURE( pFlySave->nSttNd.GetIndex() <= pFlySave->nEndNd.GetIndex(),
                 "Fly hat falschen Bereich" );
 
 
@@ -395,7 +396,7 @@ void SwRTFParser::SetFlysInDoc()
         // patch from cmc for #i52542#
         if (pSttNd->GetIndex() + 1 == pSttNd->EndOfSectionIndex())
         {
-            ASSERT(!this, "nothing in this frame, not legal");
+            OSL_ENSURE(!this, "nothing in this frame, not legal");
             delete pFlySave;
             continue;
         }
@@ -1293,7 +1294,7 @@ void SwRTFParser::InsPicture( const String& rGrfNm, const Graphic* pGrf,
             aFlySet.Put(aSurroundItem);
         }
 
-        SwFrmFmt* pFlyFmt = pDoc->Insert( *pPam,
+        SwFlyFrmFmt* pFlyFmt = pDoc->Insert( *pPam,
                     rGrfNm, aEmptyStr,		// Name der Graphic !!
                     pGrf,
                     &aFlySet,				// Attribute fuer den FlyFrm
@@ -1305,6 +1306,26 @@ void SwRTFParser::InsPicture( const String& rGrfNm, const Graphic* pGrf,
         _SetPictureSize( *pGrfNd, pPos->nNode,
                         (SfxItemSet&)pFlyFmt->GetAttrSet(),
                         pPicType );
+        if( pPicType )
+        {
+            PictPropertyNameValuePairs::const_iterator aIt = pPicType->aPropertyPairs.begin();
+            PictPropertyNameValuePairs::const_iterator aEnd = pPicType->aPropertyPairs.end();
+            while( aIt != aEnd)
+            {
+                if( aIt->first.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM( "wzDescription") ))
+                {
+                    SwXFrame::GetOrCreateSdrObject( pFlyFmt );
+                    pDoc->SetFlyFrmDescription( *(pFlyFmt), aIt->second );
+                }
+                else if( aIt->first.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM( "wzName") ))
+                {
+                    SwXFrame::GetOrCreateSdrObject( pFlyFmt );
+                    pDoc->SetFlyFrmTitle( *(pFlyFmt), aIt->second );
+                }    
+                ++aIt;
+            }
+        }    
+    
     }
 
     if( pGrfAttrSet )
@@ -1446,7 +1467,7 @@ void SwRTFParser::_SetPictureSize( const SwNoTxtNode& rNd,
 
 void SwRTFParser::GetPageSize( Size& rSize )
 {
-    ASSERT(!maSegments.empty(), "not possible");
+    OSL_ENSURE(!maSegments.empty(), "not possible");
     if (maSegments.empty())
     {
         rSize.Width() = 12240 - 1800 - 1800;
@@ -1628,4 +1649,4 @@ void SwRTFParser::ReadOLEData()
 }
 #endif
 
-/* vi:set tabstop=4 shiftwidth=4 expandtab: */
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
