@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -36,14 +37,10 @@
 
 #include <sfx2/app.hxx>
 
-#ifndef _CMDID_H
 #include <cmdid.h>
-#endif
 #include <hintids.hxx>
 #include <swtypes.hxx>
-#ifndef _GLOBALS_HRC
 #include <globals.hrc>
-#endif
 #include <svx/xtable.hxx>
 #include <uitool.hxx>
 #include <editeng/sizeitem.hxx>
@@ -61,9 +58,7 @@
 #include "uiitems.hxx"
 #include "swmodule.hxx"
 #include "view.hxx"
-/*-- 06.02.2002 15:25:39---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 SwTextGridPage::SwTextGridPage(Window *pParent, const SfxItemSet &rSet) :
     SfxTabPage(pParent, SW_RES(TP_TEXTGRID_PAGE), rSet),
     aGridTypeFL             (this, SW_RES(FL_GRID_TYPE       )),
@@ -193,22 +188,16 @@ SwTextGridPage::SwTextGridPage(Window *pParent, const SfxItemSet &rSet) :
         aCharWidthMF.Show();
     }
 }
-/*-- 06.02.2002 15:25:40---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 SwTextGridPage::~SwTextGridPage()
 {
 }
-/*-- 06.02.2002 15:25:40---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 SfxTabPage *SwTextGridPage::Create(Window *pParent, const SfxItemSet &rSet)
 {
     return new SwTextGridPage(pParent, rSet);
 }
-/*-- 06.02.2002 15:25:40---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 BOOL    SwTextGridPage::FillItemSet(SfxItemSet &rSet)
 {
     BOOL bRet = FALSE;
@@ -239,9 +228,7 @@ BOOL    SwTextGridPage::FillItemSet(SfxItemSet &rSet)
         pView->GetVLineal().DrawTicks();
     return bRet;
 }
-/*-- 06.02.2002 15:25:40---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void    SwTextGridPage::Reset(const SfxItemSet &rSet)
 {
     if(SFX_ITEM_AVAILABLE <= rSet.GetItemState(RES_TEXTGRID, TRUE))
@@ -284,9 +271,7 @@ void    SwTextGridPage::Reset(const SfxItemSet &rSet)
     aPrintCB.SaveValue();
     aColorLB.SaveValue();
 }
-/*-- 06.02.2002 15:25:41---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void    SwTextGridPage::ActivatePage( const SfxItemSet& rSet )
 {
     aExampleWN.Hide();
@@ -295,16 +280,12 @@ void    SwTextGridPage::ActivatePage( const SfxItemSet& rSet )
     aExampleWN.Show();
     aExampleWN.Invalidate();
 }
-/*-- 06.02.2002 15:25:41---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 int SwTextGridPage::DeactivatePage( SfxItemSet* )
 {
     return LEAVE_PAGE;
 }
-/* -----------------------------08.02.2002 11:57------------------------------
 
- ---------------------------------------------------------------------------*/
 void SwTextGridPage::PutGridItem(SfxItemSet& rSet)
 {
         SwTextGridItem aGridItem;
@@ -336,9 +317,7 @@ void SwTextGridPage::PutGridItem(SfxItemSet& rSet)
             pView->GetVLineal().SetLineHeight((long)(aTextSizeMF.GetValue(FUNIT_TWIP)/56.7));
         }
 }
-/* -----------------------------08.02.2002 10:54------------------------------
 
- ---------------------------------------------------------------------------*/
 void SwTextGridPage::UpdatePageSize(const SfxItemSet& rSet)
 {
     if( SFX_ITEM_UNKNOWN !=  rSet.GetItemState( RES_FRAMEDIR, TRUE ))
@@ -405,9 +384,7 @@ void SwTextGridPage::UpdatePageSize(const SfxItemSet& rSet)
         }
     }
 }
-/* -----------------------------30.05.2008 14:12------------------------------
 
- ---------------------------------------------------------------------------*/
 void SwTextGridPage::SetLinesOrCharsRanges(FixedText & rField, const sal_Int32 nValue )
 {
     String aFieldStr = String::CreateFromAscii("( 1 -");
@@ -415,9 +392,7 @@ void SwTextGridPage::SetLinesOrCharsRanges(FixedText & rField, const sal_Int32 n
     aFieldStr += String::CreateFromAscii(" )");
     rField.SetText( aFieldStr );
 }
-/* -----------------------------06.02.2002 15:24------------------------------
 
- ---------------------------------------------------------------------------*/
 USHORT* SwTextGridPage::GetRanges()
 {
     static USHORT __FAR_DATA aPageRg[] = {
@@ -425,9 +400,7 @@ USHORT* SwTextGridPage::GetRanges()
         0};
     return aPageRg;
 }
-/* -----------------------------08.02.2002 10:56------------------------------
 
- ---------------------------------------------------------------------------*/
 IMPL_LINK(SwTextGridPage, CharorLineChangedHdl, SpinField*, pField)
 {
     //if in squared mode
@@ -474,8 +447,7 @@ IMPL_LINK(SwTextGridPage, CharorLineChangedHdl, SpinField*, pField)
     GridModifyHdl(0);
     return 0;
 }
-/* -----------------------------04.09.2006 15:46------------------------------
- ---------------------------------------------------------------------------*/
+
 IMPL_LINK(SwTextGridPage, TextSizeChangedHdl, SpinField*, pField)
 {
     //if in squared mode
@@ -518,9 +490,7 @@ IMPL_LINK(SwTextGridPage, TextSizeChangedHdl, SpinField*, pField)
     GridModifyHdl(0);
     return 0;
 }
-/* -----------------------------22.04.2002 14:53------------------------------
 
- ---------------------------------------------------------------------------*/
 IMPL_LINK(SwTextGridPage, GridTypeHdl, RadioButton*, pButton)
 {
     sal_Bool bEnable = &aNoGridRB != pButton;
@@ -547,17 +517,13 @@ IMPL_LINK(SwTextGridPage, GridTypeHdl, RadioButton*, pButton)
     GridModifyHdl(0);
     return 0;
 }
-/* -----------------------------22.04.2002 15:46------------------------------
 
- ---------------------------------------------------------------------------*/
 IMPL_LINK(SwTextGridPage, DisplayGridHdl, CheckBox*, EMPTYARG)
 {
     aPrintCB.Enable(aDisplayCB.IsChecked());
     return 0;
 }
-/* -----------------------------08.02.2002 11:54------------------------------
 
- ---------------------------------------------------------------------------*/
 IMPL_LINK(SwTextGridPage, GridModifyHdl, void*, EMPTYARG)
 {
     const SfxItemSet& rOldSet = GetItemSet();
@@ -570,3 +536,4 @@ IMPL_LINK(SwTextGridPage, GridModifyHdl, void*, EMPTYARG)
     return 0;
 }
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
